
Details of external packages
============================

Packages are in alphabetical order.

.. default-role:: code

.. toctree::
   :maxdepth: 1

   4ti2
   _bootstrap
   _cibuildwheel_local_a
   _cibuildwheel_local_b
   _cibuildwheel_local_c
   _cibuildwheel_local_windows
   _develop
   _prereq
   _recommended
   _sagemath
   abelfunctions
   acsv
   admcycles
   alabaster
   anyio
   appdirs
   appnope
   argon2_cffi
   argon2_cffi_bindings
   arithmat
   arrow
   asttokens
   async_lru
   attrs
   auditwheel_or_delocate
   awali
   babel
   barvinok
   beautifulsoup4
   beniget
   benzene
   biopython
   bleach
   bliss
   boolean_cayley_graphs
   boost_cropped
   brial
   buckygen
   bzip2
   cachetools
   calver
   cbc
   ccache
   cddlib
   certifi
   certlin
   cffi
   chardet
   charset_normalizer
   cibuildwheel
   circkit
   clarabel
   cliquer
   cluster_pictures
   cmake
   cmr
   cocoalib
   colorama
   comm
   compgit
   configure
   conrey_dirichlet_characters
   contourpy
   conway_polynomials
   coxeter3
   cppy
   cppzmq
   csdp
   cunningham_tables
   curl
   curver
   cutgeneratingfunctionology
   cvolume
   cvxopt
   cvxpy
   cycler
   cylp
   cysignals
   cython
   d3js
   database_cremona_ellcurve
   database_cubic_hecke
   database_jones_numfield
   database_knotinfo
   database_kohel
   database_mutation_class
   database_odlyzko_zeta
   database_stein_watkins
   database_stein_watkins_mini
   database_symbolic_data
   dateutil
   dd_functions
   debugpy
   decorator
   deformation
   defusedxml
   dependent_bterms
   distlib
   docutils
   dot2tex
   dsdp
   dual_pairs
   e_antic
   ecl
   eclib
   ecm
   ecos_python
   editables
   eigen
   eigenmorphic
   elementary_vectors
   elliptic_curves
   entrypoints
   euler_product
   exceptiongroup
   execnet
   executing
   fastjsonschema
   fflas_ffpack
   ffmpeg
   filelock
   flatsurf
   flex
   flint
   flit_core
   fonttools
   fplll
   fpylll
   fqdn
   free_fonts
   freetype
   fricas
   frobby
   furo
   gap
   gap3
   gap_packages
   gap_pkg_cddinterface
   gap_pkg_curlinterface
   gap_pkg_float
   gap_pkg_jupyterkernel
   gap_pkg_normalizinterface
   gast
   gc
   gcaops
   gcc
   gcg
   gdb
   gdbm
   gengetopt
   gettext
   gf2x
   gfan
   gfortran
   giac
   git
   github_cli
   gitpython
   givaro
   glpk
   glucose
   gmp
   gmpy2
   gnulib
   gnumake_tokenpool
   googletest
   gp2c
   graphs
   graphviz
   gsl
   h11
   hatchling
   highs
   highspy
   hilbert_modular_group
   hodge_diamond_cutter
   httpcore
   httpx
   hypigu
   hypothesis
   iconv
   idna
   igraph
   imagemagick
   imagesize
   iml
   importlib_metadata
   importlib_resources
   indelstopo
   info
   iniconfig
   ipykernel
   ipympl
   ipython
   ipython_genutils
   ipython_pygments_lexers
   ipywidgets
   isl
   isoduration
   jedi
   jinja2
   jmol
   joblib
   json5
   jsonpointer
   jsonschema
   jsonschema_specifications
   jupyter_client
   jupyter_core
   jupyter_events
   jupyter_jsmol
   jupyter_lsp
   jupyter_server
   jupyter_server_terminals
   jupyter_sphinx
   jupyterlab
   jupyterlab_mathjax2
   jupyterlab_pygments
   jupyterlab_server
   jupyterlab_widgets
   kenzo
   kerrgeodesic_gw
   khoca
   kissat
   kiwisolver
   latte_int
   lcalc
   lefschetz_family
   libatomic_ops
   libbraiding
   libffi
   libgd
   libgraphviz
   libhomfly
   libjpeg
   liblzma
   libnauty
   libogg
   libpng
   libsemigroups
   libuuid
   libxml2
   lidia
   lie
   linbox
   llvm
   lrcalc
   lrcalc_python
   lrslib
   m4ri
   m4rie
   macaulay2
   marimo
   markupsafe
   mathics
   mathjax
   matplotlib
   matplotlib_inline
   matroid_database
   maxima
   mclf
   mcqd
   meataxe
   memory_allocator
   meson
   meson_python
   mistune
   modular_decomposition
   modular_resolution
   moment_cone
   mongo_c_driver
   mpc
   mpfi
   mpfr
   mpfrcx
   mpmath
   mpsolve
   msinvar
   msolve
   multipolynomial_bases
   nauty
   nbclient
   nbconvert
   nbformat
   ncurses
   nest_asyncio
   networkx
   nibabel
   ninja_build
   nlohmann_json
   normaliz
   notebook
   notebook_shim
   notedown
   ntl
   numerical_interactive_mip
   numpy
   onetbb
   openblas
   openssl
   ore_algebra
   osqp_python
   overrides
   p_group_cohomology
   packaging
   palp
   pandoc
   pandoc_attributes
   pandocfilters
   papilo
   pari
   pari_elldata
   pari_galdata
   pari_galpol
   pari_nflistdata
   pari_nftables
   pari_seadata
   pari_seadata_big
   pari_seadata_small
   parso
   patch
   patchelf
   pathspec
   pdf2svg
   perl_app_perlbrew
   perl_cpan_polymake_prereq
   perl_term_readline_gnu
   pexpect
   phitigra
   pickleshare
   pillow
   pip
   pkgconf
   pkgconfig
   planarity
   plantri
   platformdirs
   playwright
   pluggy
   ply
   polylib
   polymake
   polytopes_db
   polytopes_db_4d
   ppl
   pplite
   pplitepy
   pplpy
   pplpy_doc
   primecount
   primecountpy
   primesieve
   prometheus_client
   prompt_toolkit
   psutil
   ptyprocess
   pure_eval
   py4ti2
   pybind11
   pybtex
   pycosat
   pycparser
   pycryptosat
   pygcgopt
   pygments
   pygraphviz
   pynormaliz
   pyparsing
   pyproject_api
   pyproject_hooks
   pyproject_metadata
   pyscipopt
   pytest
   pytest_mock
   pytest_xdist
   python3
   python_build
   python_flint
   python_igraph
   python_json_logger
   pythran
   pytz
   pytz_deprecation_shim
   pyx
   pyyaml
   pyzmq
   qdldl_python
   qepcad
   qhull
   r
   r_jupyter
   readline
   realalg
   recip
   referencing
   regina
   requests
   rfc3339_validator
   rfc3986_validator
   roman_numerals
   rpds_py
   rpy2
   rst2ipynb
   rubiks
   rw
   saclib
   sage_bootstrap
   sage_conf
   sage_docbuild
   sage_numerical_backends_coin
   sage_numerical_backends_cplex
   sage_numerical_backends_gurobi
   sage_setup
   sage_sws2rst
   sagelib
   sagemath_benzene
   sagemath_bliss
   sagemath_brial
   sagemath_buckygen
   sagemath_categories
   sagemath_cddlib
   sagemath_cliquer
   sagemath_cmr
   sagemath_combinat
   sagemath_coxeter3
   sagemath_database_cremona_ellcurve
   sagemath_database_cunningham
   sagemath_database_jones_numfield
   sagemath_database_kohel
   sagemath_database_mutation_class
   sagemath_database_odlyzko_zeta
   sagemath_database_polytopes_4d
   sagemath_database_stein_watkins
   sagemath_database_stein_watkins_mini
   sagemath_database_symbolic_data
   sagemath_doc_html
   sagemath_doc_pdf
   sagemath_ecl
   sagemath_eclib
   sagemath_environment
   sagemath_flint
   sagemath_fricas
   sagemath_frobby
   sagemath_gap
   sagemath_gap_pkg_agt_data
   sagemath_gap_pkg_caratinterface
   sagemath_gap_pkg_cddinterface
   sagemath_gap_pkg_ctbllib_data
   sagemath_gap_pkg_curlinterface
   sagemath_gap_pkg_difsets_data
   sagemath_gap_pkg_factint_data
   sagemath_gap_pkg_float
   sagemath_gap_pkg_irredsol_data
   sagemath_gap_pkg_jupyterkernel
   sagemath_gap_pkg_normalizinterface
   sagemath_gap_pkg_numericalsgps_data
   sagemath_gap_pkg_primgrp_data
   sagemath_gap_pkg_rcwa_data
   sagemath_gap_pkg_semigroups
   sagemath_gap_pkg_sglppow_data
   sagemath_gap_pkg_simpcomp_data
   sagemath_gap_pkg_smallgrp_data
   sagemath_gap_pkg_smallsemi_data
   sagemath_gap_pkg_sonata_data
   sagemath_gap_pkg_tomlib_data
   sagemath_gap_pkg_transgrp_data
   sagemath_gap_pkg_unitlib_data
   sagemath_gap_pkg_yangbaxter_data
   sagemath_gfan
   sagemath_giac
   sagemath_glpk
   sagemath_glucose
   sagemath_graphs
   sagemath_groups
   sagemath_gsl
   sagemath_highs
   sagemath_homfly
   sagemath_iml
   sagemath_kenzo
   sagemath_kissat
   sagemath_latte_4ti2
   sagemath_lcalc
   sagemath_libbraiding
   sagemath_libecm
   sagemath_linbox
   sagemath_lrslib
   sagemath_m4ri_m4rie
   sagemath_macaulay2
   sagemath_macaulay2_jupyterkernel
   sagemath_maxima
   sagemath_mcqd
   sagemath_meataxe
   sagemath_modules
   sagemath_msolve
   sagemath_nauty
   sagemath_ntl
   sagemath_objects
   sagemath_palp
   sagemath_pari
   sagemath_pari_elldata
   sagemath_pari_galdata
   sagemath_pari_galpol
   sagemath_pari_nflistdata
   sagemath_pari_nftables
   sagemath_pari_seadata
   sagemath_pari_seadata_big
   sagemath_pari_seadata_small
   sagemath_planarity
   sagemath_plantri
   sagemath_plot
   sagemath_polyhedra
   sagemath_polymake
   sagemath_qepcad
   sagemath_rankwidth
   sagemath_repl
   sagemath_rubiks
   sagemath_schemes
   sagemath_singular
   sagemath_sirocco
   sagemath_standard_no_symbolics
   sagemath_symbolics
   sagemath_sympow
   sagemath_tachyon
   sagemath_tdlib
   sagemath_topcom
   sagenb_export
   sagetex
   sbcl
   sboxanalyzer
   schubertpy
   scikit_build_core
   scip
   scip_sdp
   scipy
   scs
   semigroups
   send2trash
   setuptools
   setuptools_scm
   sign_crn
   sign_vectors
   singular
   singular_jupyter
   sirocco
   six
   slabbe
   snappy
   sniffio
   snowballstemmer
   soplex
   sortedcontainers
   soupsieve
   sphinx
   sphinx_basic_ng
   sphinx_copybutton
   sphinx_inline_tabs
   sphinxcontrib_applehelp
   sphinxcontrib_devhelp
   sphinxcontrib_htmlhelp
   sphinxcontrib_jsmath
   sphinxcontrib_qthelp
   sphinxcontrib_serializinghtml
   sphinxcontrib_websupport
   sqlalchemy
   sqlite
   stack_data
   stallings_graphs
   stdpairs
   suitesparse
   surf
   surface_dynamics
   symengine
   symengine_py
   symmetrica
   sympow
   sympy
   tachyon
   tdlib
   terminado
   texlive
   texlive_luatex
   texttable
   threejs
   tides
   tinycss2
   tomli
   topcom
   tornado
   tox
   train_track
   traitlets
   trove_classifiers
   twostage
   types_python_dateutil
   typing_extensions
   tzdata
   tzlocal
   uri_template
   urllib3
   valgrind
   virtualenv
   wcwidth
   webcolors
   webencodings
   websocket_client
   wheel
   widgetsnbextension
   xeus
   xeus_gp
   xeus_zmq
   xindy
   xz
   zeromq
   zftools
   zipp
   zlib

.. default-role::

